# Show running .NET-Version
# Stop-Process -Name notepad -Force -ErrorAction SilentlyContinue
$execruntime = [System.Reflection.Assembly]::GetExecutingAssembly().ImageRuntimeVersion
#
$ExportPath = $env:TEMP
$ExportFile = "drucker-info-$env:Username@$env:computername.txt"
Remove-Item $ExportPath\$ExportFile -Force -ErrorAction SilentlyContinue
#

# ---- Ausgabe --- START ------ 
$DateTXT = Get-Date  -format "dd.MM.yyyy - hh:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8
Write-Output "Drucker-Info Tool - Ver. 1.2.12 (15.11.2022) / .NET Runtime $execruntime" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Download https:\\www.hekret.de\pcinfo" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
# Write-Output "`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erstellt von Benutzer '$env:userdomain\$env:USERNAME @ $env:computername '`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "Datensatz erstellt am $DateTXT`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#

Write-Host "------------------------------------------------------------------"
Write-Host "Drucker-Info Tool - Ver. 1.2.12 (15.11.2022) / .NET Runtime $execruntime"
Write-Host "Download https:\\www.hekret.de\pcinfo"
Write-Host "------------------------------------------------------------------`r`n"

# --- Info Machine / User --- START ---
$machinename = (Get-CimInstance -Class:Win32_Computersystem).Name
$domain = (Get-CimInstance Win32_ComputerSystem).Domain

# ActiveDirectory Site abfragen und Fehler abfangen.
try {
    $adsite = [System.DirectoryServices.ActiveDirectory.ActiveDirectorySite]::GetComputerSite().Name
    }
    catch
    {
    # Write-Host $PSItem.Exception.Message
    Set-Variable -Name adsite -Value "-"
    }
#
#
$dr = Get-CimInstance -Class win32_computersystem | Select-Object -ExpandProperty domainrole
$domainrole = switch ($dr) {
    0 {"Standalone Workstation"} 
    1 {"Member Workstation"} 
    2 {"Standalone Server"} 
    3 {"Member Server"} 
    4 {"Backup Domain Controller"} 
    5 {"Primary Domain Controller"} 
    default {"Unknown"} 
    } # end switch



write-Output "
Domain Machine Info:`
    Computername: ............... $machinename`
    ActiveDirectory: ............ $domain`
    Site: ....................... $adsite`
    Domain Role: ................ $domainrole`
`
Domain User Info:`
    ActiveDirectory: ............ $env:userdomain`
    LogonServer: ................ $env:logonserver`
    UserName: ................... $env:USERNAME`
    `
    `
    " | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

# --- Info Machine / User --- END ---

# Write-Host "Status:`n"
Write-Host "collecting Data ...  / sammle Daten ...`r`n"
#

Write-Host "installed Printers and Printer Driver / installierte Drucker und Drucketreiber`n"
Write-Output "------------ installed Printers and Printer Driver / installierte Drucker und Drucketreiber --------------- START -----" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
  # List of Printers
Get-Printer | Sort-Object -Property  Name | Format-Table -AutoSize | Out-File -Width 500 "$ExportPath\$ExportFile" -Encoding utf8 -Append

  # List of Printer Drivers
Get-PrinterDriver | Select-Object Name,@{
    n="DriverVersion";e={

        $ver = $_.DriverVersion
        $rev = $ver -band 0xffff
        $build = ($ver -shr 16) -band 0xffff
        $minor = ($ver -shr 32) -band 0xffff
        $major = ($ver -shr 48) -band 0xffff
        "$major.$minor.$build.$rev"

    }
},Manufacturer,PrinterEnvironment | Sort-Object -Property  Name | Format-Table -AutoSize | Out-File -Width 500 "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append

# ---- Ausgabe --- END ------ 
#
$DateTXT = Get-Date  -format "dd.MM.yyyy - hh:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erfassung abgeschlossen: $DateTXT" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "_______________ - End of File - ______________________`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
# Get-Content $ExportPath\$ExportFile
# pause
Start-Process notepad.exe $ExportPath\$ExportFile
